#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.16
visibility:           public
id:                   gitit-0.16-3XMHWR1oJNP8z9LLF4Tw5u
key:                  gitit-0.16-3XMHWR1oJNP8z9LLF4Tw5u
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  a77dde465bc8474399e23e6d66aeac20
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Server Network.Gitit.State Network.Gitit.Types
    Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.16-3XMHWR1oJNP8z9LLF4Tw5u
depends:
    HStringTemplate-0.8.8-25RfUiRxvBZ66eXlbuit2e
    HTTP-4000.5.0-C22JFzmy2XY1pGTJJRDjaD
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.2.0-6vy5nFkYOklEBUzF5CRv7u base-4.18.2.1
    base64-bytestring-1.2.1.0-JBjEAAOdpBm2IYrolgjJx9
    blaze-html-0.9.2.0-17FkYPGue7ZAHMHHyLr7B4 bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-5ZZ8lhNhKbLFInLlyWhMlg
    feed-1.3.2.1-qSXRHZSJU25mNvlCzWGxH filepath-1.4.300.1
    filestore-0.6.5.1-5tgDoc3QZBOH4syUr6DSh7 ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-IbByXy9jCniBKgFNagQN1k
    hoauth2-2.14.0-CbpjKaH5vlP7dos4cBSAsd
    hslogger-1.3.2.0-2bh2QeUYUW8D5IrU2Zjsgw
    http-client-tls-0.3.6.4-GpdGf98kidO2rAaJB77bKV
    http-conduit-2.3.9.1-1UysXAtzoTS7lyZP0KaEZa
    json-0.11-Dk8HRpib8IrEFejxXondjx mtl-2.3.1
    network-3.1.4.0-8HZ2mHT7KyE1ZVQfwLbJCE
    network-bsd-2.8.1.0-HBdbsvtzQtN1RKMIBgMy6C
    network-uri-2.6.4.2-FHtb4mND2mdHJ6uOX3EAJs
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.1.0-BqlNSykfGRW9DWa86GWf7W
    pandoc-3.10.2-15eUPAStvtpHMRHQmrwZVt
    pandoc-types-1.23.1.2-GSvb4yy0JYI8h6WGCyx7HL parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-GfiOoTkiJ8dHrTrBUL8yXz
    recaptcha-0.1.0.4-Fzt3LJlpL2D4nncijFJP5P
    safe-0.3.21-242vtiZp8xiFH4MzHCK9jy
    skylighting-0.14.7-EgkAU0Hh1yw1x4XvimLRo7
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl syb-0.7.4-BzNZTTWYfk9HN4YOl0udkE
    tagsoup-0.14.8-8kPaXtaYapP8ASwIPYpORz
    temporary-1.3-EJjX5K17BD86XZ5zCqX06b text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-7Mroi1zVUYOLFlY6XqjdW8
    url-2.1.3-FnoMg0Amz5x5iDNEWuwHDq
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    uuid-1.3.16.1-DPU1pyFvmFvGXgW1eSh0Oa xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-BJAPIc3ZpEX9Hl5GLrN5ZY
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-33ANdjNXDCL929e6w4oepO
    zlib-0.7.1.0-9PtbtAjlwdC8Samdliu9GX

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

